entidade_annotations library

Validation annotations and classes

Classes

BuildBuilder
Annotation that instructs the code generator to build a subclass of BuildBuilder for the class to which it is applied
Builder<T>
BuildResult<T>
CopyValue<T>
Data
Annotation that instructs the code generator to build an extension of the class to which it is applied that adds a copyWith method, and == and hashCode methods that implement equivalence.
DeepCollectionEquality
Deep equality on collections.
DefaultsProvider
EmailAddress
Annotation that indicates the field to which it is applied to should be formatted as an email address
EmailAddressValidationError
Represents an error indicating that a required value is missing
EntityPermissions
Defines the CRUD permissions for a PODO
ErrorList
Contains the results of a validation check
ListItemErrorList
Represents the validation errors, errorList, of an object item that is part of a list, list at the index itemIndex
ListPropertyValidation
Validation error applied to properties of List type, composed of multiple errors
PropertyValidation
Represents a ValidationError specific to a property that can contain multiple errors
Range<T>
Annotation that indicates the field to which it is applied to has a range of values between min and max
RangeValidationError<T>
Represents an error indicating that a required value is missing
RegularExpression
Annotation that indicates the field to which it is applied to has to math the given regular expression
RegularExpressionValidationError
Represents an error indicating that a required value is missing
Required
Annotation that indicates the field to which it is applied to is required
RequiredValidationError
Represents an error indicating that a required value is missing
StringLength
Annotation that indicates the field to which it is applied to has a length that ranges from minLength to maxLength
StringLengthValidationError
Represents an error indicating that a required value is missing
Validatable
Annotation that indicates that the class to which it is applied to is a validatable class
ValidationError
Represents a validation error
Validator
Performs validation on an object

Constants

builder → const BuildBuilder
data → const Data
defaultsProvider → const DefaultsProvider
emailAddress → const EmailAddress
required → const Required
validatable → const Validatable